#import "ViewController.h"

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    
    NSArray *data = @[@1,@3,@5,@6,@3,@4];
    _dsh = [[IGCategorySeriesDataSourceHelper alloc]initWithValues:data];
    
    _chart = [[IGChartView alloc]initWithFrame:self.view.frame];
    _series = (IGColumnSeries*)[_chart addSeriesForType:[IGColumnSeries class] usingKey:@"series" withDataSource:_dsh firstAxisKey:@"x" secondAxisKey:@"y"];
    [_chart addSeriesForType:[IGColumnSeries class] usingKey:@"series2" withDataSource:_dsh firstAxisKey:@"x" secondAxisKey:@"y"];
    
    _chart.delegate = self;
    _chart.theme = [self getCustomTheme];
    
    IGCategoryXAxis *x = [_chart findAxisByKey:@"x"];
    
    x.strokeThickness = 5;
    x.stroke = [[IGBrush alloc]initWithColor:[UIColor blueColor]];
    
    x.majorStrokeThickness = 3;
    x.majorStroke = [[IGBrush alloc]initWithColor:[UIColor redColor]];
    
    x.minorStrokeThickness = 2;
    x.minorStroke = [[IGBrush alloc]initWithColor:[UIColor yellowColor]];


    
    [self.view addSubview:_chart];
}

-(NSInteger)getIndexOfDataPoint:(IGCategoryPoint*)point
{
    for (IGSeries *series in _chart.series)
    {
        if (series.dataPoints != nil && [series.dataPoints containsObject:point])
        {
            return [series.dataPoints indexOfObject:point];
        }
    }
    return -1;
}

-(NSString *)chartView:(IGChartView *)chartView labelForAxis:(IGAxis *)axis withItem:(NSObject *)item
{
    if ([item isKindOfClass:[NSNumber class]])
    {
        return [((NSNumber*)item) stringValue];
    }
    
    if ([item isKindOfClass:[IGCategoryPoint class]])
    {
        NSInteger index = [self getIndexOfDataPoint:item];
        if (index == 0)
            return @"";
        
        return ((IGCategoryPoint*)item).label;
    }
    
    return @"";
}

-(IGChartThemeDefinition *)getCustomTheme
{
    IGChartThemeDefinition* ret = [[IGChartThemeDefinition alloc]init];
    ret.name = @"IGChartDefaultTheme";
    ret.font = [UIFont fontWithName:@"Helvetica" size:16];
    ret.fontColor = [[IGBrush alloc] initWithR:0 andG:0 andB:0 andA:1];
    ret.backgroundColor = [UIColor whiteColor];
    ret.legendFont = [UIFont fontWithName:@"Helvetica" size:12];
    ret.legendFontColor = [[IGBrush alloc] initWithR:0 andG:0 andB:0 andA:1];
    ret.legendBorderThickness = 1;
    ret.legendPalette = [[IGChartPaletteItem alloc]init];
    ret.legendPalette.name = @"legend";
    ret.legendPalette.color = [[IGBrush alloc] initWithR:0.9 andG:0.9 andB:0.9 andA:0.8];
    ret.legendPalette.outlineColor = [[IGBrush alloc] initWithR:0.7 andG:0.7 andB:0.7 andA:1];
    
    IGChartPaletteItem* item1 = [[IGChartPaletteItem alloc] init];
    item1.name = @"item1";
    item1.outlineColor = [[IGBrush alloc] initWithR:0.69 andG:0.75 andB:0.79 andA:1];
    item1.color = [[IGBrush alloc] initWithR:0.31 andG:0.65 andB:0.74 andA:1];
    [ret.seriesPalettes addObject:item1];
    
    IGChartPaletteItem* item2 = [[IGChartPaletteItem alloc] init];
    item2.name = @"item2";
    item2.outlineColor = [[IGBrush alloc] initWithR:0.47 andG:0.53 andB:0.58 andA:1];
    item2.color = [[IGBrush alloc] initWithR:0.98 andG:0.40 andB:0.33 andA:1];
    [ret.seriesPalettes addObject:item2];
    
    IGChartPaletteItem* item3 = [[IGChartPaletteItem alloc] init];
    item3.name = @"item3";
    item3.outlineColor = [[IGBrush alloc] initWithR:0.31 andG:0.38 andB:0.42 andA:1];
    item3.color = [[IGBrush alloc] initWithR:0.99 andG:0.76 andB:0.23 andA:1];
    [ret.seriesPalettes addObject:item3];
    
    IGChartPaletteItem* item4 = [[IGChartPaletteItem alloc] init];
    item4.name = @"item4";
    item4.outlineColor = [[IGBrush alloc] initWithR:0.21 andG:0.27 andB:0.31 andA:1];
    item4.color = [[IGBrush alloc] initWithR:0.23 andG:0.39 andB:0.6 andA:1];
    [ret.seriesPalettes addObject:item4];
    
    IGChartPaletteItem* item5 = [[IGChartPaletteItem alloc] init];
    item5.name = @"item5";
    item5.outlineColor = [[IGBrush alloc] initWithR:0.08 andG:0.17 andB:0.23 andA:1];
    item5.color = [[IGBrush alloc] initWithR:0.57 andG:0.69 andB:0.29 andA:1];
    [ret.seriesPalettes addObject:item5];
    
    IGChartPaletteItem* axis = [[IGChartPaletteItem alloc] init];
    axis.name = @"axis";
    axis.outlineColor = [[IGBrush alloc] initWithR:0.60 andG:0.62 andB:0.64 andA:1];
    axis.color = [[IGBrush alloc] initWithR:0.60 andG:0.62 andB:0.64 andA:1];
    ret.axisPalette = axis;
    
    return ret;
}

@end

